TrustedToken

Struct TrustedToken 

pub struct TrustedToken { /* private fields */ }
A TrustedToken is returned by either a verify() or decrypt() operation and represents a validated token.

It represents a authenticated and non-tampered token. It does not validate additional things, such as claims that may be within the token payload itself. These must still be validated separately.

However, using the crate::public and crate::local API will automatically handle claims validation. Any validated claims may be retrieved with TrustedToken::payload_claims().

Implementations

Source

impl TrustedToken

pub fn header(&self) -> &str

Get the header that is used for this token.

pub fn payload(&self) -> &str

Get the payload that is used for this token.

pub fn payload_claims(&self) -> Option<&Claims>

Available on crate feature std only.

Return the optional and validated Claims parsed from the tokens payload.

  • None: If no Claims have been parsed or validated.
  • Some: If some Claims have been parsed AND validated.
pub fn footer(&self) -> &[u8]

Get the footer used to create the token.

Empty if None was used during creation.

pub fn implicit_assert(&self) -> &[u8]

Get the implicit assertion used to create the token.

Empty if None was used during creation. If token was created using V2, then it will always be empty.