pub struct TrustedToken { /* private fields */ }Expand description
A TrustedToken is returned by either a verify() or decrypt() operation and represents
a validated token.
It represents a authenticated and non-tampered token. It does not validate additional things, such as claims that may be within the token payload itself. These must still be validated separately.
However, using the crate::public and crate::local API will automatically handle claims
validation. Any validated claims may be retrieved with TrustedToken::payload_claims().
Implementations
Sourceimpl TrustedToken
impl TrustedToken
Sourcepub fn payload_claims(&self) -> Option<&Claims>
Available on crate feature std only.
pub fn payload_claims(&self) -> Option<&Claims>
std only.Get the footer used to create the token.
Empty if None was used during creation.
Sourcepub fn implicit_assert(&self) -> &[u8] ⓘ
pub fn implicit_assert(&self) -> &[u8] ⓘ
Get the implicit assertion used to create the token.
Empty if None was used during creation.
If token was created using V2, then it will always be empty.